From 9db5197f82781c685a8ea3f354c114216aa8519e Mon Sep 17 00:00:00 2001
From: "arseny.kapoulkine"
 <arseny.kapoulkine@99668b35-9821-0410-8761-19e4c4f06640>
Date: Mon, 11 Dec 2006 13:04:04 +0000
Subject: Default parsing mode now does not include parsing PI and comments.

git-svn-id: http://pugixml.googlecode.com/svn/trunk@19 99668b35-9821-0410-8761-19e4c4f06640
---
 src/pugixml.hpp | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

(limited to 'src')

diff --git a/src/pugixml.hpp b/src/pugixml.hpp
index 42a7950..009b10a 100644
--- a/src/pugixml.hpp
+++ b/src/pugixml.hpp
@@ -59,8 +59,8 @@ namespace pugi
 	const unsigned int parse_eol_cdata			= 0x00004000; ///< Perform EOL handling in CDATA sections
 	const unsigned int parse_check_end_tags		= 0x00010000; ///< Check start and end tag names and return error if names mismatch
 	const unsigned int parse_match_end_tags		= 0x00020000; ///< Try to find corresponding start tag for an end tag
-	///< Set all flags, except parse_ws_pcdata and parse_trim_attribute
-	const unsigned int parse_default			= 0x00FFFFFF & ~parse_ws_pcdata & ~parse_trim_attribute;
+	///< Set all flags, except parse_ws_pcdata, parse_trim_attribute, parse_pi and parse_comments
+	const unsigned int parse_default			= 0x00FFFFFF & ~parse_ws_pcdata & ~parse_trim_attribute & ~parse_pi & ~parse_comments;
 	const unsigned int parse_noset				= 0x80000000; ///< Parse with flags in xml_parser
 
 	const unsigned int parse_w3c				= parse_pi | parse_comments | parse_cdata |
-- 
cgit v1.2.3